embassy-stm32

Crates

git

Versions

stm32u535cc

Flavors

TransferConfig

Struct TransferConfig 

pub struct TransferConfig {
Show 17 fields pub iwidth: OspiWidth, pub instruction: Option<u32>, pub isize: AddressSize, pub idtr: bool, pub adwidth: OspiWidth, pub address: Option<u32>, pub adsize: AddressSize, pub addtr: bool, pub abwidth: OspiWidth, pub alternate_bytes: Option<u32>, pub absize: AddressSize, pub abdtr: bool, pub dwidth: OspiWidth, pub ddtr: bool, pub dummy: DummyCycles, pub dqse: bool, pub sioo: bool,
}
OSPI transfer configuration.

Fields

iwidth: OspiWidth

Instruction width (IMODE)

instruction: Option<u32>

Instruction Id

isize: AddressSize

Number of Instruction Bytes

idtr: bool

Instruction Double Transfer rate enable

adwidth: OspiWidth

Address width (ADMODE)

address: Option<u32>

Device memory address. In indirect mode, this value + the length of the data being read or written must be within configured Config::device_size, otherwise the transfer returns an error.

adsize: AddressSize

Number of Address Bytes

addtr: bool

Address Double Transfer rate enable

abwidth: OspiWidth

Alternate bytes width (ABMODE)

alternate_bytes: Option<u32>

Alternate Bytes

absize: AddressSize

Number of Alternate Bytes

abdtr: bool

Alternate Bytes Double Transfer rate enable

dwidth: OspiWidth

Data width (DMODE)

ddtr: bool

Data Double Transfer rate enable

dummy: DummyCycles

Number of dummy cycles (DCYC)

dqse: bool

Data strobe (DQS) management enable

sioo: bool

Send instruction only once (SIOO) mode enable Enable this to improve memory-mapped latency. Ensure your device supports this mode. Some manufacturers call this ‘Continuous Read’ mode and require specific bits to be set in alternate bytes (e.g. Winbound W25Q) and specific disable sequences.